@@ -1,10 +1,11 @@
 package PDL::DSP::Windows;
 
-our $VERSION = '0.008004'; # TRIAL
+our $VERSION = '0.008005'; # TRIAL
 
 use strict;
 use warnings;
 
+use PDL::Bad ();
 use PDL::Basic ();
 use PDL::Core ();
 use PDL::FFT ();
@@ -21,6 +22,10 @@ use constant {
     HAVE_BESSEL        => eval { require PDL::GSLSF::BESSEL }          || 0,
     HAVE_GNUPLOT       => eval { require PDL::Graphics::Gnuplot }      || 0,
     USE_FFTW_DIRECTION => version->parse($PDL::VERSION) <= v2.007,
+    I => version->parse($PDL::VERSION) > v2.054 ? PDL::Core::pdl('i') : do {
+        require PDL::Complex; # Deprecated in 2.055
+        PDL::Complex::i();
+    },
 };
 
 # These constants are left in our namespace for historical reasons
@@ -193,14 +198,16 @@ PDL::DSP::Windows - Window functions for signal processing
     use PDL;
     use PDL::DSP::Windows 'window';
 
-    my $window;
+    # Get a piddle with a window's samples with the helper
+    my $samples = window( 10, tukey => { params => .5 });
 
-    # Create a window with the helper
-    $window = window( 10, 'tukey', { params => .5 });
+    # Or construct a window object with the same parameters
+    my $window = PDL::DSP::Windows->new( 10, tukey => { params => .5 });
 
-    # Or with the OO constructor, which is the same
-    $window = PDL::DSP::Windows->new( 10, 'tukey', { params => .5 });
+    # These two are equivalent
+    $samples = $window->samples;
 
+    # The window object gives access to additional methods
     print $window->coherent_gain, "\n";
 
     $window->plot; # Requires PDL::Graphics::Gnuplot
@@ -335,10 +342,9 @@ sub list_windows {
                 next;
             }
 
-            for my $alias ( grep /$expr/i, @{ $window_aliases{$name} // [] } ) {
-                push @match, "$name (alias $alias)";
-                next;
-            }
+            push @match,
+                map "$name (alias $_)",
+                grep /$expr/i, @{ $window_aliases{$name} // [] };
         }
     }
     else {
@@ -358,9 +364,9 @@ sub list_windows {
 
 =for ref
 
-Create an instance of a Windows object. If C<ARGS> are given, the instance
+Create an instance of a window object. If C<ARGS> are given, the instance
 is initialized. C<ARGS> are interpreted in exactly the same way as arguments
-the subroutine L</window>.
+for the L</window> subroutine.
 
 =for example
 
@@ -386,8 +392,8 @@ sub new {
 
 =for ref
 
-Initialize (or reinitialize) a Windows object. C<ARGS> are interpreted in
-exactly the same way as arguments the subroutine L</window>.
+Initialize (or reinitialize) a window object. C<ARGS> are interpreted in
+exactly the same way as arguments for the L</window> subroutine.
 
 =for example
 
@@ -890,9 +896,9 @@ sub scallop_loss {
     my $w = shift->samples;
 
     # Adapted from https://stackoverflow.com/a/40912607
-    my $num = abs( ( $w * exp( -( ( PDL::Core::pdl("1i") * PDL::sequence($w) * PI ) / $w->nelem ) ) )->sum );
+    my $num = $w * exp( -( I()->im * PDL::sequence($w) * PI / $w->nelem ) );
 
-    20 * PDL::Ops::log10( $num / abs($w)->sum );
+    20 * PDL::Ops::log10( abs( $num->sum ) / abs($w)->sum );
 }
 
 =head1 WINDOW FUNCTIONS
@@ -2050,6 +2056,7 @@ delete @PDL::DSP::Windows::{qw(
     HAVE_BESSEL
     HAVE_GNUPLOT
     USE_FFTW_DIRECTION
+    I
 )};
 
 1;
